@@ -53,7 +53,7 @@ struct DrawStruct DrawData;	/* Universal structure drawing variables */
 
 extern gint NumFrameRI;		/* Contains which frame is about to be 
 				   read from the input data */
-extern float FrameTime;		/* Contains time of frame just shown */
+extern double FrameTime;		/* Contains time of frame just shown */
 extern FILE *NewFP;		/* Filepointer to new file if one has 
 				   been chosen, otherwise = NULL */
 
@@ -329,10 +329,10 @@ printf("Fetching and setting coordinates of pointer at scene.\n");
 #endif
         sprintf(xstr, "X: %5.3f   Y: %5.3f",
 		(((params->xmax2[NumFrame]-params->xmin2[NumFrame])
-		*(x-xborder)/(float) params->absxsize)+
+		*(x-xborder)/(double) params->absxsize)+
 		params->xmin2[NumFrame]),(((params->ymax2[NumFrame]
 		-params->ymin2[NumFrame])*(params->absysize-(y-yborder))/
-		(float) params->absysize))+params->ymin2[NumFrame]);
+		(double) params->absysize))+params->ymin2[NumFrame]);
         gtk_entry_set_text ((GtkEntry *) coord_entry, xstr);
       
     return TRUE;
@@ -496,7 +496,7 @@ printf("Setting entryboxes.\n");
 #if Debug
 printf("%s\n",params->dumpname);
 #endif
-		if (params->dumpname[0]!=(char) NULL) {
+		if (params->dumpname[0] != '\0') {
 #if Debug
 printf("Creating image of frame to dump.\n");
 #endif
@@ -968,7 +968,7 @@ printf("Initializing GTK.\n");
 
     params.interval = 0;
 
-    params.dumpname[0] = (char) NULL;
+    params.dumpname[0] = '\0';
 
     strcpy(params.timedelim,TIMESTRING);
 
