@@ -53,28 +53,6 @@ struct GlobalParams newparams;		/* New values if OK is pressed, else ignored */
 gboolean usescol,usedump,filewopen;	/* Help variables to define usage of 
 					   specific features */
 
-
-/************************************************************************/
-/* This function just kills the filebrowser window. 			*/
-/************************************************************************/
-void destroyfbw (GtkWidget *widget, gpointer data) {
-    gtk_widget_destroy(filew);
-    filewopen=FALSE;
-}
-
-
-/************************************************************************/
-/* This function gets called when the filebrowser window is killed, it 	*/
-/* gets the selected filename from the filebrowser and puts it in the	*/
-/* filename entry.							*/
-/************************************************************************/
-void file_ok_sel (GtkWidget *widget, GtkFileSelection *fs) {
-    gtk_entry_set_text( GTK_ENTRY (file_entry),
-			gtk_file_selection_get_filename (GTK_FILE_SELECTION (fs)));
-    destroyfbw(widget,fs);
-}
-
-
 /************************************************************************/
 /* This function just kills the setup window. 				*/
 /************************************************************************/
@@ -89,22 +67,23 @@ void destroy (GtkWidget *widget, gpointer data) {
 /* and shows it.							*/
 /************************************************************************/
 void filebrowser(GtkWidget *widget, gpointer data) {
-        
-    /* Create a new file selection widget */
-    filew = gtk_file_selection_new ("File selection");
-        
-    g_signal_connect (G_OBJECT (filew), "destroy",
-		      G_CALLBACK (destroyfbw), &filew);
+    GtkWidget *dialog;
+    
+    dialog = gtk_file_chooser_dialog_new ("Open File",
+				          GTK_WINDOW (setupwin),
+				          GTK_FILE_CHOOSER_ACTION_OPEN,
+				          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				          GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+				          NULL);
+				          
+    if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
+	char *filename;
+    	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+	gtk_entry_set_text( GTK_ENTRY (file_entry),filename);
+    	g_free (filename);
+    }
 
-    /* Connect the ok_button to file_ok_sel function */
-    g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (filew)->ok_button),
-                        "clicked", G_CALLBACK (file_ok_sel), filew );
-        
-    /* Connect the cancel_button to destroy the widget */
-    g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (filew)->cancel_button),
-                               "clicked", G_CALLBACK (destroyfbw), G_OBJECT (filew));
-    filewopen=TRUE;
-    gtk_widget_show_all(filew);
+    gtk_widget_destroy (dialog);
 }
 
 
@@ -114,7 +93,7 @@ void filebrowser(GtkWidget *widget, gpointer data) {
 /* and spinners.							*/
 /************************************************************************/
 void okeypressed(GtkWidget *widget, struct GlobalParams *params) {
-    gfloat tmpvalue;
+    double tmpvalue;
     sprintf(params->file,"%s",gtk_entry_get_text(GTK_ENTRY (file_entry)));
     tmpvalue = gtk_spin_button_get_value(GTK_SPIN_BUTTON (xspinner));
 
@@ -181,7 +160,7 @@ void okeypressed(GtkWidget *widget, struct GlobalParams *params) {
 	sprintf(params->dumpname,"%s",gtk_entry_get_text(GTK_ENTRY (dump_entry)));
     }
     else {
-	*(params->dumpname)=(char) NULL;
+	*(params->dumpname) = '\0';
     }
 
     sprintf(params->timedelim,"%s",gtk_entry_get_text(GTK_ENTRY (timedel_entry)));
@@ -209,7 +188,7 @@ void okeypressed(GtkWidget *widget, struct GlobalParams *params) {
 /* the setup window.							*/
 /************************************************************************/
 void redrawpressed(GtkWidget *widget, struct GlobalParams *params) {
-    gfloat tmpvalue;
+    double tmpvalue;
     sprintf(params->file,"%s",gtk_entry_get_text(GTK_ENTRY (file_entry)));
     tmpvalue = gtk_spin_button_get_value(GTK_SPIN_BUTTON (xspinner));
     if (tmpvalue>0.0 || tmpvalue<0.0) {
@@ -275,7 +254,7 @@ void redrawpressed(GtkWidget *widget, struct GlobalParams *params) {
 	sprintf(params->dumpname,"%s",gtk_entry_get_text(GTK_ENTRY (dump_entry)));
     }
     else {
-	*(params->dumpname)=(char) NULL;
+	*(params->dumpname) = '\0';
     }
 
     params->fxyz=newparams.fxyz;
@@ -577,7 +556,7 @@ void toggle_scol (GtkWidget *widget, gpointer data)
 /************************************************************************/
 void setspinlimits(GtkWidget *widget, gpointer data) 
 {
-gfloat value1,value2;
+double value1,value2;
 
     value1 = gtk_spin_button_get_value(GTK_SPIN_BUTTON (xspinner));
     value2 = gtk_spin_button_get_value(GTK_SPIN_BUTTON (x2spinner));
@@ -631,7 +610,6 @@ GtkWidget *file_label,*column_label,*ff_label,*cxyz_label,*separator;
 GtkWidget *cube_label,*x_label,*y_label,*z_label,*xcol_label,*ycol_label,*zcol_label,*tcol_label,*ssize_label;
 GtkWidget *ssx_label,*ssy_label,*sleep_label,*d_label,*header,*col_label,*misc_label,*draw_label,*empty_label;
 GtkWidget *hboxtd;
-GtkTooltips *tooltip;
 GSList *group;
 
     newparams.mode=params->mode;
@@ -703,9 +681,7 @@ GSList *group;
     gtk_entry_set_max_length(GTK_ENTRY(file_entry), 160);    
     g_signal_connect (G_OBJECT (file_entry), "changed",
 		      G_CALLBACK (filechange),G_OBJECT (setupwin));
-
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,file_entry,inputfilett,NULL);
+    gtk_widget_set_tooltip_text(file_entry,inputfilett);
 
     browseb = gtk_button_new_with_mnemonic ("_Browse");
     g_signal_connect (G_OBJECT (browseb), "clicked",
@@ -757,8 +733,7 @@ GSList *group;
 //                                     GTK_SHADOW_OUT);
     gtk_box_pack_start (GTK_BOX (hbox_cube), cube_label, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (hbox_cube), cubespinner, TRUE, TRUE, 0);
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,cubespinner,cubett,NULL);
+    gtk_widget_set_tooltip_text(cubespinner,cubett);
 
 
     x_label = gtk_label_new("X : ");
@@ -831,18 +806,12 @@ GSList *group;
     gtk_box_pack_start (GTK_BOX (vboxcuber), zspinner, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vboxcuberm), z2spinner, TRUE, TRUE, 0);
 
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,xspinner,mintt,NULL);
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,yspinner,mintt,NULL);
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,zspinner,mintt,NULL);
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,x2spinner,maxtt,NULL);
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,y2spinner,maxtt,NULL);
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,z2spinner,maxtt,NULL);
+    gtk_widget_set_tooltip_text(xspinner,mintt);
+    gtk_widget_set_tooltip_text(yspinner,mintt);
+    gtk_widget_set_tooltip_text(zspinner,mintt);
+    gtk_widget_set_tooltip_text(x2spinner,maxtt);
+    gtk_widget_set_tooltip_text(y2spinner,maxtt);
+    gtk_widget_set_tooltip_text(z2spinner,maxtt);
 
     separator = gtk_hseparator_new ();
     gtk_box_pack_start (GTK_BOX (vboxleft), separator, FALSE, TRUE, 3);
@@ -862,8 +831,7 @@ GSList *group;
     gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (xcspinner), FALSE);
     gtk_box_pack_start (GTK_BOX (vboxxcl), xcol_label, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vboxxcr), xcspinner, TRUE, TRUE, 0);
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,xcspinner,xcoltt,NULL);
+    gtk_widget_set_tooltip_text(xcspinner,xcoltt);
 
     ycol_label = gtk_label_new("Y column : ");
 
@@ -873,8 +841,7 @@ GSList *group;
     gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (ycspinner), FALSE);
     gtk_box_pack_start (GTK_BOX (vboxxcl), ycol_label, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vboxxcr), ycspinner, TRUE, TRUE, 0);
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,ycspinner,ycoltt,NULL);
+    gtk_widget_set_tooltip_text(ycspinner,ycoltt);
 
     zcol_label = gtk_label_new("Z column : ");
 
@@ -884,8 +851,7 @@ GSList *group;
     gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (zcspinner), FALSE);
     gtk_box_pack_start (GTK_BOX (vboxxcl), zcol_label, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vboxxcr), zcspinner, TRUE, TRUE, 0);
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,zcspinner,zcoltt,NULL);
+    gtk_widget_set_tooltip_text(zcspinner,zcoltt);
 
     tcol_label = gtk_label_new("t column : ");
 
@@ -895,8 +861,7 @@ GSList *group;
     gtk_spin_button_set_wrap (GTK_SPIN_BUTTON (tcspinner), FALSE);
     gtk_box_pack_start (GTK_BOX (vboxxcl), tcol_label, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vboxxcr), tcspinner, TRUE, TRUE, 0);
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,tcspinner,tcoltt,NULL);
+    gtk_widget_set_tooltip_text(tcspinner,tcoltt);
 
     separator = gtk_hseparator_new ();
     gtk_box_pack_start (GTK_BOX (vboxleft), separator, FALSE, TRUE, 3);
@@ -916,8 +881,7 @@ GSList *group;
 	gtk_widget_set_sensitive (timedel_entry, TRUE);
 	gtk_widget_set_sensitive (timedel_label, TRUE);
     }
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,timedel_entry,timedeltt,NULL);
+    gtk_widget_set_tooltip_text(timedel_entry,timedeltt);
 
     ff_label = gtk_label_new("Input file format");
     gtk_box_pack_start (GTK_BOX (vboxright), ff_label, TRUE, TRUE, 0);
@@ -946,8 +910,7 @@ GSList *group;
     gtk_box_pack_start (GTK_BOX (vboxright), usetypescheck, TRUE, TRUE, 0);
     if (params->usetypes) gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (usetypescheck), TRUE);
     else gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (usetypescheck), FALSE);
-    tooltip = gtk_tooltips_new();
-    gtk_tooltips_set_tip (tooltip,usetypescheck,coltypett,NULL);
+    gtk_widget_set_tooltip_text(usetypescheck,coltypett);
 
     separator = gtk_hseparator_new ();
     gtk_box_pack_start (GTK_BOX (vboxright), separator, FALSE, TRUE, 3);
